"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.onPreBootstrap = void 0;

var _fs = require("fs");

var _simpleGit = _interopRequireDefault(require("simple-git"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Check if a path exists.
 *
 * @param {string} path
 * @return {Promise<boolean>}
 */
const exists = async path => {
  try {
    await _fs.promises.access(path);
    return true;
  } catch {
    return false;
  }
};

const onPreBootstrap = async ({
  reporter
}, options) => {
  var _options$gitOptions, _options$branch;

  if (!options.repository) {
    reporter.panic('Missing required option `repository` for gatsby-plugin-git-clone.');
    return;
  }

  if (!options.path) {
    reporter.panic('Missing required option `path` for gatsby-plugin-git-clone.');
    return;
  }

  const git = (0, _simpleGit.default)((_options$gitOptions = options.gitOptions) !== null && _options$gitOptions !== void 0 ? _options$gitOptions : {});

  if (await exists(options.path)) {
    await git.cwd(options.path);
    await git.pull('origin', options.branch, ['--rebase', '--autostash', '--depth', '1']);
    return;
  }

  await git.clone(options.repository, options.path, ['--branch', (_options$branch = options.branch) !== null && _options$branch !== void 0 ? _options$branch : 'master', '--depth', '1', '--single-branch']);
};

exports.onPreBootstrap = onPreBootstrap;